@@ -1,10 +1,11 @@
 import json
+import os
 from typing import List, Tuple, Union
 
 import numpy as np
 
 from worker.data.api import API
-from worker.data.enums import EventTypes
+from worker.data.enums import EventTypes, Environment
 from worker.exceptions import NotFound
 
 
@@ -68,6 +69,80 @@ def delete_collection_data_of_asset_id(asset_id: int, collections: Union[str, li
         worker.delete(path=path, query=query)
 
 
+def point_main_envs(env: str):
+    """
+    The purpose of this function is to point main environment variables to
+    the provided environment. This method updates the following environment
+    variables:
+    - API_ROOT_URL
+    - API_KEY
+    - CACHE_URL
+
+    :param env: the environment to point to
+    :return:
+    """
+    if not env:
+        return
+
+    # validating the environment
+    Environment(env)
+
+    api_url = os.getenv(f"API_ROOT_URL_{env}")
+    api_key = os.getenv(f"API_KEY_{env}")
+    cache_url = os.getenv(f"CACHE_URL_{env}")
+
+    if not all([api_url, api_key, cache_url]):
+        raise ValueError("Missing environment variables!")
+
+    new_envs = {
+        'API_ROOT_URL': api_url,
+        'API_KEY': api_key,
+        'CACHE_URL': cache_url
+    }
+
+    os.environ.update(new_envs)
+
+
+def setup_api_worker(env: str, app_name: str):
+    """
+    Set up the Corva API worker
+    :param env: environment ['local', 'qa', 'staging', 'production']
+    :param app_name:
+    :return: api worker
+    """
+    # validating the environment
+    Environment(env)
+
+    api_url = os.getenv(f"API_ROOT_URL_{env}")
+    api_key = os.getenv(f"API_KEY_{env}")
+
+    options = {
+        "api_url": api_url,
+        "api_key": api_key,
+        "app_name": app_name
+    }
+    api_worker = API(**options)
+
+    return api_worker
+
+
+def setup_redis_worker(env: str) -> Tuple:
+    """
+    Set up the Redis worker
+    :param env: environment ['local', 'qa', 'staging', 'production']
+    :return: redis worker
+    """
+    # validating the environment
+    Environment(env)
+
+    cache_url = os.getenv(f"CACHE_URL_{env}")
+
+    import redis
+    redis_worker = redis.Redis.from_url(cache_url, decode_responses=True)
+
+    return redis_worker
+
+
 def get_drillstring_by_id(drillstring_id: str) -> Union[dict, None]:
     """
     Get the drillstring from API by providing mongodb _id
